
.. image:: pyrf_logo.png
   :alt: PyRF logo

PyRF Documentation
==================

Contents:

.. toctree::
   :maxdepth: 2

   usermanual
   reference
   examples
   plans


Hardware Support
----------------

This library currently supports development for the `WSA4000 Platform`_,
but may support additional hardware in the future.

.. _WSA4000 Platform: http://www.thinkrf.com/products.html

Links
-----

* `Official github page <https://github.com/pyrf/pyrf>`_
* `Documentation for this API <http://pyrf.rtfd.org>`_
* `WSA4000 Documentation <http://www.thinkrf.com/resources>`_

GUI Example Included
--------------------

.. image:: wsa4000demo.png
   :alt: wsa4000gui screen shot

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

